'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

const React = require('react');
const raf = require('raf');
const TopPanel = require('./components/panel-top');
const MiddlePanel = require('./components/panel-middle');
const BottomPanel = require('./components/panel-bottom');
const Background = require('./components/background');
const environments = require('./components/environments');

class Nav extends React.PureComponent {
  constructor(props) {
    super(props);

    this.state = {
      isMobile: false,
      isOpen: false,
      activeSection: -1,
      breakpoint: 895
    };

    this.toggle = this.toggle.bind(this);
    this.setActiveSection = this.setActiveSection.bind(this);
    this.onResize = this.onResize.bind(this);
  }

  componentDidMount() {
    this.setState({
      isMobile: window.innerWidth <= this.state.breakpoint
    });

    window.addEventListener('resize', function () {
      if (this.rafId) return;

      this.rafId = raf(this.onResize);
    }.bind(this));
  }

  onResize() {
    const { isMobile, breakpoint } = this.state;
    const { innerWidth } = window;

    if (isMobile && innerWidth > breakpoint) {
      this.setState({ isMobile: false, isOpen: false, activeSection: -1 });
      document.body.classList.toggle('no-scroll', false);
    } else if (!isMobile && innerWidth <= breakpoint) {
      this.setState({ isMobile: true, activeSection: -1 });
    }

    this.rafId = undefined;
  }

  setActiveSection(activeSection) {
    this.setState({ activeSection });
  }

  toggle(isOpen) {
    isOpen = isOpen || !this.state.isOpen;

    if (this.state.isMobile) {
      document.body.classList.toggle('no-scroll', isOpen);
    }

    this.setState({ isOpen });
  }

  render() {
    const { isOpen, activeSection } = this.state;
    const props = Object.assign({}, this.props, environments[this.props.environment]);

    return React.createElement(
      'nav',
      { className: 'nav-panel flex flex--center-y flex--wrap' },
      React.createElement(TopPanel, {
        downloadUrl: props.downloadUrl,
        downloadJmpValue: props.downloadJmpValue,
        includeSearch: props.includeSearch,
        host: props.environment === 'com' ? '' : 'https://www.mongodb.com',
        sections: props.topSections,
        searchUrl: props.searchUrl,
        contactUrl: props.contactUrl }),
      React.createElement(MiddlePanel, _extends({}, this.state, {
        logoUrl: props.logoUrl,
        tagline: props.tagline,
        logoLink: props.logoLink,
        sections: props.sections,
        toggle: this.toggle,
        setActiveSection: this.setActiveSection })),
      React.createElement(
        Background,
        {
          isMobile: this.state.isMobile,
          setActiveSection: this.setActiveSection,
          isOpaque: isOpen || activeSection !== -1 || props.isOpaque,
          isOpen: isOpen || activeSection !== -1 },
        React.createElement(BottomPanel, _extends({}, this.state, {
          midSections: props.sections,
          sections: props.subsections }))
      )
    );
  }
}

const { bool, string, array } = React.PropTypes;

Nav.propTypes = {
  topSections: array,
  sections: array,
  subsections: array,

  isOpaque: bool,
  includeSearch: bool,

  environment: string,
  searchUrl: string,
  contactUrl: string,
  downloadUrl: string,
  downloadJmpValue: string,
  logoUrl: string,
  logoLink: string,
  tagline: string
};

Nav.defaultProps = {
  environment: 'com'
};

module.exports = Nav;