const React = require('react')
const SearchInput = require('./search')
const { contactIcon, downloadIcon } = require('../nav-icons')

function TopPanel (props) {
  return (
    <div className='nav-panel-top font--center'>
      <ul className='flex flex--space-between' style={{ height: '100%' }}>
        <div className='nav-panel-top__links flex flex--center-y font--center'>
          {props.sections.map(function (section, i) {
            return (
              <a
                key={i}
                className='nav-panel-top__a'
                target={section.text === 'Open Source' && props.host === '' ? '_self' : '_blank'}
                href={section.href}>
                <li className='nav-panel-top__li'>{ section.text }</li>
              </a>
            )
          })}
        </div>

        <div className='flex flex--center-y'>
          <a href={props.contactUrl}>
            <button
              className='flex flex--center-all flex--wrap nav-panel-top__contact'
              style={props.includeSearch ? {} : { marginRight: '15px' }}>
              { contactIcon }
            </button>
          </a>

          {props.includeSearch &&
          <SearchInput searchUrl={props.searchUrl} />}

          <a
            className='nav-panel-top__a'
            href={`${props.host}${props.downloadUrl}${props.downloadJmpValue === '' ? '' : `?jmp=${props.downloadJmpValue}`}`}
            target={props.host === '' ? '_self' : '_blank'}>
            <button className='btn-small btn-fill btn-fill--light-green margin--left-xs nav-panel-top__download'>
              <span style={{ verticalAlign: 'middle' }}>Download</span>
              { downloadIcon }
            </button>
          </a>
        </div>
      </ul>
    </div>
  )
}

const { string, bool, array } = React.PropTypes

TopPanel.propTypes = {
  includeSearch: bool,
  searchUrl: string,
  contactUrl: string,
  sections: array,
  host: string.isRequired,
  downloadUrl: string,
  downloadJmpValue: string
}

TopPanel.defaultProps = {
  includeSearch: true,
  searchUrl: '/search?search=',
  contactUrl: '/contact?jmp=nav',
  downloadUrl: '/download-center',
  downloadJmpValue: 'nav'
}

module.exports = TopPanel
